==> apache-hugegraph-toolchain-incubating-1.0.0-src.tar.gz: apache-hugegraph-toolchain-incubating-1.0.0-src/hugegraph-client/src/main/java/org/apache/hugegraph/driver/MetricsManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package org.apache.hugegraph.driver;

import java.util.Map;

import org.apache.hugegraph.api.metrics.MetricsAPI;
import org.apache.hugegraph.client.RestClient;

public class MetricsManager {

    private MetricsAPI metricsAPI;

    public MetricsManager(RestClient client) {
        this.metricsAPI = new MetricsAPI(client);
    }

    public Map<String, Map<String, Object>> backend() {
        return this.metricsAPI.backend();
    }

    public Map<String, Object> backend(String graph) {
        return this.metricsAPI.backend(graph);
    }

    public Map<String, Map<String, Object>> system() {
        return this.metricsAPI.system();
    }

    /**
     * The nesting level is too deep, may need to optimize the server first
     */
    public Map<String, Map<String, Object>> all() {
        return this.metricsAPI.all();
    }
}

==> apache-hugegraph-toolchain-incubating-1.3.0-src.tar.gz: apache-hugegraph-toolchain-incubating-1.3.0-src/hugegraph-client/src/main/java/org/apache/hugegraph/driver/MetricsManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package org.apache.hugegraph.driver;

import java.util.Map;

import org.apache.hugegraph.api.metrics.MetricsAPI;
import org.apache.hugegraph.client.RestClient;

public class MetricsManager {

    private MetricsAPI metricsAPI;

    public MetricsManager(RestClient client) {
        this.metricsAPI = new MetricsAPI(client);
    }

    public Map<String, Map<String, Object>> backend() {
        return this.metricsAPI.backend();
    }

    public Map<String, Object> backend(String graph) {
        return this.metricsAPI.backend(graph);
    }

    public Map<String, Map<String, Object>> system() {
        return this.metricsAPI.system();
    }

    /**
     * The nesting level is too deep, may need to optimize the server first
     */
    public Map<String, Map<String, Object>> all() {
        return this.metricsAPI.all();
    }

    public String allWithPromFormat() {
        return this.metricsAPI.allWithPromFormat();
    }

    public Map<String, Map<String, Object>> statistics() {
        return this.metricsAPI.statistics();
    }

    public String statisticsWithPromFormat() {
        return this.metricsAPI.statisticsWithPromFormat();
    }
}
